package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.model.receive.ReceiveContants;
import com.vendor.burn.serial.workers.WorkerUtility;
import java.util.StringTokenizer;

public class ReceiveHelper implements ReceiveContants {
  public static long convertToNumber(String strNum) {
    if (strNum == null || strNum.trim().length() == 0)
      return -1L; 
    strNum = strNum.toLowerCase();
    long unit = 1L;
    int index;
    if ((index = strNum.indexOf("g")) != -1) {
      unit = 1073741824L;
    } else if ((index = strNum.indexOf("k")) != -1) {
      unit = 1024L;
    } else if ((index = strNum.indexOf("m")) != -1) {
      unit = 1048576L;
    } else if ((index = strNum.indexOf("b")) != -1) {
      unit = 1L;
    } else {
      index = strNum.length();
    } 
    try {
      if (strNum.contains("0x")) {
        index = strNum.length();
        return Long.parseLong(strNum.substring(2, index), 16);
      } 
      return Long.parseLong(strNum.substring(0, index)) * unit;
    } catch (NumberFormatException e) {
      return -1L;
    } 
  }
  
  public static String convertUnit(long num) {
    String unit = "";
    if (num == 0L)
      return "0"; 
    if (num % 1024L != 0L)
      return "" + num; 
    unit = "K";
    num /= 1024L;
    if (num < 1024L)
      return "" + num + num; 
    if (num % 1024L != 0L)
      return "" + num + num; 
    unit = "M";
    num /= 1024L;
    return "" + num + num;
  }
  
  public static long getNandChipSize(String received) {
    int indexOf = received.indexOf("Nand(");
    if (indexOf == -1)
      return -1L; 
    indexOf = received.indexOf(":", indexOf);
    if (indexOf == -1)
      return -1L; 
    String substring = received.substring(indexOf);
    return getChipSize(substring);
  }
  
  public static long getNandBlockSize(String received) {
    int indexOf = received.indexOf("Nand(");
    if (indexOf == -1)
      return -1L; 
    indexOf = received.indexOf(":", indexOf);
    if (indexOf == -1)
      return -1L; 
    String substring = received.substring(indexOf);
    return getBlockSize(substring);
  }
  
  public static long getChipSize(String received) {
    int indexOf = received.indexOf("Chip:");
    if (indexOf == -1)
      return -1L; 
    int indexOf2 = received.indexOf(" ", indexOf);
    if (indexOf2 == -1)
      return -1L; 
    String substring = received.substring(indexOf + "Chip:".length(), indexOf2);
    StringTokenizer stringTokenizer = new StringTokenizer(substring);
    int countTokens = stringTokenizer.countTokens();
    if (countTokens > 1 && 
      stringTokenizer.hasMoreElements())
      substring = (String)stringTokenizer.nextElement(); 
    String trim = substring.trim().replace("*", ",");
    String[] split = trim.split(",");
    if (split.length < 2)
      return -1L; 
    long result = 1L;
    for (String string : split) {
      long convertToNumber = convertToNumber(string.trim());
      if (convertToNumber == -1L)
        return -1L; 
      result *= convertToNumber;
    } 
    return result;
  }
  
  public static long getBlockSize(String received) {
    return getSize(received, "Block:");
  }
  
  public static long getOobSize(String received) {
    return getSize(received, "OOB:");
  }
  
  public static long getSize(String received, String prefix) {
    if (received == null || received.trim().length() == 0)
      return 0L; 
    int startIndex = received.indexOf(prefix);
    if (startIndex == -1)
      return 0L; 
    startIndex += prefix.length();
    int endIndex = received.indexOf(" ", startIndex);
    if (endIndex == -1)
      return 0L; 
    String strSize = received.substring(startIndex, endIndex).toLowerCase();
    return convertToNumber(strSize);
  }
  
  public static long getPageSize(String received) {
    return getSize(received, "Page:");
  }
  
  public static String getVersion(String received) {
    if (received == null || received.trim().length() == 0)
      return null; 
    received = received.toLowerCase();
    int startIndex = received.indexOf("version");
    if (startIndex == -1)
      return null; 
    int endIndex = received.indexOf("\r\n", startIndex);
    if (endIndex == -1)
      return null; 
    return received.substring(startIndex, endIndex);
  }
  
  public static long getChipBranchSeries7ChipSize(String received) {
    int indexOf = received.indexOf("Chip:");
    if (indexOf == -1)
      return -1L; 
    int indexOf2 = received.indexOf(" ", indexOf);
    if (indexOf2 == -1)
      return -1L; 
    String subString = received.substring(indexOf + "Chip:".length(), indexOf2);
    long convertToNumber = convertToNumber(subString.trim());
    if (convertToNumber == -1L)
      return -1L; 
    return convertToNumber * 1024L;
  }
}
